---
name: Bug report
about: Report an error or unexpected behaviour
title: "Bug: "
labels: bug
assignees: jonathanfox5
---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

1. [If applicable] Language the media is in '....'
2. Use these configuration options '....'
3. Type this command '...'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Configuration (please complete the following information):**

- OS: [e.g. Windows, macOS, Linux]
- Using CPU / GPU processing [if known]

**Additional context**
Add any other context about the problem here.
